pub enum AskError {
Send(SendError),
ResponseDropped,
Actor(ActorError),
}Expand description
Errors reported when awaiting a response from an actor.
Variants
Send(SendError)
Failed to send the request.
ResponseDropped
The actor dropped the response channel without sending a reply.
Actor(ActorError)
The actor returned an error.