pub enum SpawnError {
MissingRuntime,
DuplicateChild(ActorId),
NameTaken {
name: String,
system: String,
},
SystemNameTaken(String),
}Expand description
Failures encountered when spawning a child actor.
Variants
MissingRuntime
No Tokio runtime was found in the current context.
DuplicateChild(ActorId)
A child with the same ID is already registered.
NameTaken
An actor with the given name is already registered in the system.
Fields
SystemNameTaken(String)
An actor system with the given name already exists.